Documentation
¶
Index ¶
- func GetMove(name string) (moves.Move, error)
- func GetPokemon(name string) (pokemon.Pokemon, error)
- func GetPokemonAbility(name string) (pokemon.Ability, error)
- func GetPokemonCharacteristic(id int) (pokemon.Characteristic, error)
- func GetPokemonColor(name string) (pokemon.Color, error)
- func GetPokemonEggGroup(name string) (pokemon.EggGroup, error)
- func GetPokemonForm(name string) (pokemon.Form, error)
- func GetPokemonGender(name string) (pokemon.Gender, error)
- func GetPokemonGrowthRate(name string) (pokemon.GrowthRate, error)
- func GetPokemonHabitat(name string) (pokemon.Habitat, error)
- func GetPokemonLocationArea(name string) ([]pokemon.LocationArea, error)
- func GetPokemonNature(name string) (pokemon.Nature, error)
- func GetPokemonPokeathlonStats(name string) (pokemon.PokeathlonStat, error)
- func GetPokemonShape(name string) (pokemon.Shape, error)
- func GetPokemonSpecies(name string) (pokemon.Species, error)
- func GetPokemonStat(name string) (pokemon.Stat, error)
- func GetPokemonType(name string) (pokemon.Type, error)
- func GetResourceList(endpoint string, count int) (resource.List, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetMove ¶ added in v0.3.0
GetMove returns a Move struct containing information about the Move with the given name.
func GetPokemon ¶
GetPokemon returns a Pokemon struct containing information about the Pokemon with the given name.
func GetPokemonAbility ¶ added in v0.4.0
GetPokemonAbility returns an Ability struct containing information about the Ability with the given name.
func GetPokemonCharacteristic ¶ added in v0.4.0
func GetPokemonCharacteristic(id int) (pokemon.Characteristic, error)
GetPokemonCharacteristic returns a Characteristic struct containing information about the Characteristic with the given id.
func GetPokemonColor ¶ added in v0.4.0
GetPokemonColor returns a Color struct containing information about the Color with the given name.
func GetPokemonEggGroup ¶ added in v0.4.0
GetPokemonEggGroup returns an EggGroup struct containing information about the EggGroup with the given name.
func GetPokemonForm ¶ added in v0.4.0
GetPokemonForm returns a Form struct containing information about the Form with the given name.
func GetPokemonGender ¶ added in v0.4.0
GetPokemonGender returns a Gender struct containing information about the EggGroup with the given name.
func GetPokemonGrowthRate ¶ added in v0.4.0
func GetPokemonGrowthRate(name string) (pokemon.GrowthRate, error)
GetPokemonGrowthRate returns a GrowthRate struct containing information about the GrowthRate with the given name.
func GetPokemonHabitat ¶ added in v0.4.0
GetPokemonHabitat returns a Habitat struct containing information about the Habitat with the given name.
func GetPokemonLocationArea ¶ added in v0.4.0
func GetPokemonLocationArea(name string) ([]pokemon.LocationArea, error)
GetPokemonLocationArea returns a PokemonLocationArea struct containing information about the PokemonLocationArea with the given name.
func GetPokemonNature ¶ added in v0.4.0
GetPokemonNature returns a Nature struct containing information about the Nature with the given name.
func GetPokemonPokeathlonStats ¶ added in v0.4.0
func GetPokemonPokeathlonStats(name string) (pokemon.PokeathlonStat, error)
GetPokemonPokeathlonStats returns a PokeathlonStat struct containing information about the PokeathlonStat with the given name.
func GetPokemonShape ¶ added in v0.4.0
GetPokemonShape returns a Shape struct containing information about the Shape with the given name.
func GetPokemonSpecies ¶ added in v0.4.0
GetPokemonSpecies returns a Species struct containing information about the Species with the given name.
func GetPokemonStat ¶ added in v0.4.0
GetPokemonStat returns a Stat struct containing information about the Stat with the given name.
func GetPokemonType ¶ added in v0.4.0
GetPokemonType returns a Type struct containing information about the Type with the given name.
Types ¶
This section is empty.