Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetMove ¶ added in v0.3.0
GetMove returns a Move struct containing information about the Move with the given name.
func GetMoveList ¶ added in v0.3.0
GetMoveList returns a list of Move names. You have to include a limit for the amount of names you want.
func GetPokemon ¶
GetPokemon returns a Pokemon struct containing information about the Pokemon with the given name.
func GetPokemonList ¶ added in v0.2.0
func GetPokemonList(limit int) (pokemon.PokemonList, error)
GetPokemonList returns a list of Pokemon names. You have to include a limit for the amount of names you want.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.